@@ -1,10 +1,12 @@
 module Serverspec::Type
   class Service < Base
-    def enabled?(level)
+    def enabled?(level, under=nil)
+      check_method = "check_service_is_enabled" + (under ? "_#{under}" : '')
+
       if level
-        @runner.check_service_is_enabled(@name, level)
+        @runner.send(check_method.to_sym, @name, level)
       else
-        @runner.check_service_is_enabled(@name)
+        @runner.send(check_method.to_sym, @name)
       end
     end
 
@@ -25,9 +27,11 @@ module Serverspec::Type
       end
     end
 
-    def monitored_by?(monitor)
+    def monitored_by?(monitor, monitor_name)
       check_method = "check_service_is_monitored_by_#{monitor}".to_sym
-      res = @runner.send(check_method, @name)
+      # use the with_name value if set instead of the service name
+      monitor_name = (monitor_name ? monitor_name : @name)
+      res = @runner.send(check_method, monitor_name)
     end
 
     def has_property?(property)
