@@ -27,7 +27,7 @@ describe service('sshd') do
   it {
     expect {
       should be_running.under('not implemented')
-    }.to raise_exception
+    }.to raise_error(/is not implemented in Specinfra/)
   }
 end
 
@@ -36,6 +36,11 @@ describe service('sshd') do
   it { should be_monitored_by(:monit) }
 end
 
+describe service('tinc') do
+  let(:stdout) { "Process 'tinc-myvpn'\r\n  status running\r\n  monitoring status  monitored" }
+  it { should be_monitored_by(:monit).with_name('tinc-myvpn') }
+end
+
 describe service('unicorn') do
   it { should be_monitored_by(:god) }
 end
@@ -44,6 +49,6 @@ describe service('sshd') do
   it {
     expect {
       should be_monitored_by('not implemented')
-    }.to raise_exception
+    }.to raise_error(NotImplementedError)
   }
 end
